#!/bin/sh
#######################################################################
## Main script for MASS data reprocessing
## Parameter: the base-name(s) of the mass- and stm-file YYMMDD.
## 
## Bulk processing may be organized as follows:
## ./remass.sh ../in/*.mass 2>remass.log

############ Program and script path settings #########################
############ (post-installation tuning only) ##########################
BKGR=./bkgr.awk
PARAM=./param.awk
DTIME=./dtime.awk
FILTER=./filter.awk
TURBDIR="./"
WEIGHTDIR=./"weight"
SPECDIR=$TURBDIR/"spectra"
RESPFILE=$TURBDIR/"data/mass_maid.crv"
#RESPFILE=$TURBDIR/"data/without_cut.crv"
ATMOS="./atmos"
ATMOSCALL=$ATMOS" -a60  -Z0.5,0.7,1,1.4,2,3,4,6,8,12,16,24  -r"$RESPFILE" -c"$RESPFILE" -w -s"$SPECDIR
OUT=./out
ERR=./err
################# Reprocessing parameters #############################
########### (Modify whenever any condition changes) ###################

# This setting regulates wrong background cleaning (RAT_F_* are OBLIGATORY!!!)
# Example: BKGR_DATA="FIXED_BG_D=1 MAX_BG_D=5 RAT_F_AB=0.37 RAT_F_BC=0.24 RAT_F_CD=0.30"
BKGR_DATA="
FIXED_BG_D=1 MAX_BG_D=5 RAT_F_AD=0.03 RAT_F_BD=0.07 RAT_F_CD=0.30
"

# Here are TRUE optics magnification, PMT characteristics and scattering (if any)
# Example: DEVICE_DATA="k=15.7 PA=1.01 PB=1.016 nA=22 nD=23 SB=0.05"
# Nonpoissons were measured 2006-10-15 and 16
DEVICE_DATA="
k=15.4 PA=1.010 PB=1.012 PC=1.008 PD=1.007 nA=22.1 nB=21.2 nC=21.0 nD=19.5 SA=0.03 SB=0.02
"

# Here we cause implausible results to be commented out
FILTER_OUT_DATA="
MAX_BG_F_D=5 MAX_CHI2=25 MIN_D=80 MAX_E_D=0.025 MAX_AE_FSEE=1.0
"

# Here we set dt=3600 or dt=-3600 ONLY for data with +/- 1 hour wrong UT reference
DTIME_DATA="
dt=0
"

################### Making reprocessing ###############################
############## (do not change anything here) ##########################
ok=1
for x in $BKGR $PARAM $DTIME $FILTER $ATMOS; do
	if [ ! -x $x ]; then
		echo "No program $x found or wrong permissions"
		echo "Make sure you start remass.sh from its directory."
		ok=0
	fi
done
for d in $WEIGHTDIR $SPECDIR $IN $OUT; do
	if [ ! -d $d ]; then
		echo "No directory $d found"
		ok=0
	fi
done
for f in $RESPFILE; do
	if [ ! -f $f ]; then
		echo "No file $f found"
		ok=0
	fi
done
if [ $ok -ne 1 ]; then exit 1; fi

for mass in `ls $@`; do
	i=`echo $mass|sed -e s/mass$//`
	o=`echo $i|sed -e sx^.*/xxg`
	stm=$i"stm"
	dt=`echo $DTIME_DATA|sed s/dt=//`
	if [ $dt != 0 -a -n $dt ]; then
		ostm=$OUT/$o"r.stm"
		echo "process $stm in $ostm"
		$DTIME $DTIME_DATA $stm >$ostm
		stm=$ostm
	fi
	omass=$OUT/$o"r.mass"
	emass=$ERR/$o"err"
	echo "process $mass with $stm in $omass"
	$BKGR $BKGR_DATA $mass |\
	$PARAM $DEVICE_DATA |\
	$DTIME $DTIME_DATA |\
	./convert.sh - $stm |\
#	tee "after" |\
	$ATMOSCALL 2>$emass |\
	$FILTER $FILTER_OUT_DATA >$omass
done
#######################################################################
